/*
 * mini_map.hpp
 *
 * Copyright (c) Stephen Thompson, 2007.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * Mini-Map class
 *
 */

#ifndef MINI_MAP_HPP
#define MINI_MAP_HPP

#include "mini_map_colour.hpp"

#include <map>
#include <vector>
using namespace std;

class Display;
class MapCoord;

class MiniMap {
public:
	MiniMap() : width(0), height(0) { }
	void create(int w, int h);

	// Accessors
	int getWidth() const { return width; }
	int getHeight() const { return height; }
	MiniMapColour getColour(const MapCoord &mc) const; // useful for LocDview::isSqMapped.
	
	// Modifiers
	void setHighlight(const MapCoord &mc, int id);  // add a 'flashing' square. 
	void setColour(const MapCoord &mc, MiniMapColour col);
	void wipe();       // sets all tile colours to zero (NB: does not affect highlights.)

	// Draw the map.
	// First version draws at "scale" pixels per map square
	// Second version draws at 3 pixels per 2 map squares.
	void draw(Display &dpy, int bl_x, int bl_y, int scale) const;
	void drawOnePointFiveScale(Display &dpy, int bl_x, int bl_y) const;
	
	enum { MAX_COLOUR = 2 };  // valid colours range from 0 to MAX_COLOUR (inclusive).
	
private:
	struct Highlighter {		
		Highlighter(const MiniMap &m);  // sets highlights to COL_HIGHLIGHT
		~Highlighter();  // resets highlights to their original colours.
		const MiniMap &mini_map;
	};
	friend struct Highlighter;

private:
	int width, height;
	mutable vector<MiniMapColour> data; // this must be mutable for Highlighter to work properly.
	struct Highlight {
		MapCoord pos;
		MiniMapColour old_colour;
	};
	map<int, Highlight> highlights;
};

#endif
