/*
 * title_screen.cpp
 *
 * Copyright (c) Stephen Thompson, 2007.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "misc.hpp"

#include "connecting_screen.hpp"
#include "knights_game.hpp"
#include "loading_screen.hpp"
#include "platform/display.hpp"
#include "title_screen.hpp"
#include "x_centre.hpp"

namespace {
	TitleScreen *tscr = 0;
}

void SetupTitleScreen(const UsefulStuff &u)
{
	ASSERT(!tscr);
	tscr = new TitleScreen(u);
	tscr->render();
	u.app2d->addObserver(tscr);
	u.app2d->setUpdateIntervalActive(-1);
	u.app2d->setUpdateIntervalInactive(-1);
	u.app2d->setRenderFast(false);
}

void StopTitleScreen(const UsefulStuff &u)
{
	if (!tscr) return;
	u.app2d->rmObserver(tscr);
	delete tscr;
	tscr = 0;
}

void TitleScreen::xcentre(int y, const char *str)
{
	XCentre(*us.display, y, str);
}

void TitleScreen::render()
{
	us.display->begin();
	xcentre(17*1, "KNIGHTS");
	xcentre(17*2, "BETA RELEASE 002");
	//3
	xcentre(17*4, "STEPHEN THOMPSON, 2007");
	//5
	xcentre(17*6, "BASED ON AMIGA GAME BY");
	xcentre(17*7, "KALLE \"REAPER\" MARJOLA, 1994");
	//8
	xcentre(17*9, "SEE LICENCE.TXT FOR");
	xcentre(17*10, "COPYRIGHT INFO");
	//11
	//12
	xcentre(17*13, "PLEASE SELECT:");
	//14
	xcentre(17*15, "HOST NETWORK GAME");
	//16
	xcentre(17*17, "JOIN NETWORK GAME");
	//18
	xcentre(17*19, "SPLIT SCREEN MODE");
	//20
	xcentre(17*21, "QUIT");
	us.display->end();
}

void TitleScreen::mouseDown(int x, int y, bool rmb)
{
	if (rmb) return; // We are only interested in left-clicks here
	
	bool ready = false;
	bool must_connect = false;
	if (y >= 17*14 && y <= 17*15) {
		// Server
		ready = true;
		us.server = true;
		must_connect = true;
	} else if (y >= 17*16 && y <= 17*17) {
		// Client
		ready = true;
		us.server = false;
		must_connect = true;
	} else if (y >= 17*18 && y <= 17*19) {
		// Split screen mode
		ready = true;
		us.server = true;
		must_connect = false;
	} else if (y >= 17*20 && y <= 17*21) {
		// Quit
		us.app2d->rmObserver(this);
		us.app2d->exitMainLoop();
	}
	
	if (ready) {
		us.display->begin(); us.display->end(); // clear the screen

		// We now remove this Observer and add a new one (via the Setup* routines).
		// This effectively transfers control to a new Observer.
		if (must_connect) {
			// Must go to ConnectingScreen (to set up the connections).
			SetupConnectingScreen(us);
		} else {
			// we can go directly to LoadingScreen
			SetupLoadingScreen(us);
		}
		StopTitleScreen(us);		
	}
}

